@@ -9,36 +9,43 @@ module PuppetMetadata
       @options  = options
     end
 
+    # @param [Date] at
+    #   The date when to generate the outputs. This affects the acceptance test
+    #   matrix, which excludes EOL operating systems. Its primary purpose is
+    #   reliable (unit) tests which don't break over time.
     # @return [Hash[Symbol, Any]] The outputs for Github Actions
-    def outputs
+    def outputs(at = nil)
       {
-        puppet_major_versions: puppet_major_versions,
         puppet_unit_test_matrix: puppet_unit_test_matrix,
-        puppet_beaker_test_matrix: puppet_beaker_test_matrix,
-        # Deprecated
-        github_action_test_matrix: github_action_test_matrix,
+        puppet_beaker_test_matrix: puppet_beaker_test_matrix(at),
       }
     end
 
     private
 
-    def puppet_major_versions
-      metadata.puppet_major_versions.sort.reverse.map do |version|
-        next if puppet_version_below_minimum?(version)
+    def beaker_major_versions
+      metadata.requirements_with_major_versions.flat_map do |requirement, versions|
+        versions.sort.reverse.filter_map do |version|
+          next if requirement_name_version_below_minimum?(version)
 
-        {
-          name: "Puppet #{version}",
-          value: version,
-          collection: "puppet#{version}",
-        }
-      end.compact
+          label = (requirement == 'openvox') ? 'OpenVox' : requirement.capitalize
+
+          {
+            name: "#{label} #{version}",
+            value: version,
+            collection: "#{requirement}#{version}",
+            requirement: requirement,
+          }
+        end
+      end
     end
 
     def puppet_unit_test_matrix
-      metadata.puppet_major_versions.sort.reverse.map do |puppet|
+      majors = metadata.requirements_with_major_versions.first[1]
+      majors.sort.reverse.map do |puppet|
         ruby = PuppetMetadata::AIO::PUPPET_RUBY_VERSIONS[puppet]
         next unless ruby
-        next if puppet_version_below_minimum?(puppet)
+        next if requirement_name_version_below_minimum?(puppet)
 
         {
           puppet: puppet,
@@ -47,24 +54,38 @@ module PuppetMetadata
       end.compact
     end
 
-    def beaker_os_releases
-      majors = puppet_major_versions
-
+    def beaker_os_releases(at = nil)
+      majors = beaker_major_versions
       distro_puppet_version = {
         name: 'Distro Puppet',
         value: nil, # We don't know the version and since it's rolling, it can be anything
         collection: 'none',
+        requirement: 'puppet',
       }
-
       metadata.operatingsystems.each do |os, releases|
         case os
         when 'Archlinux', 'Gentoo'
+          # both currently only ship puppet, not openvox yet
           yield [os, 'rolling', distro_puppet_version]
         else
           releases&.each do |release|
+            if PuppetMetadata::OperatingSystem.eol?(os, release, at)
+              message = "Skipping EOL operating system #{os} #{release}"
+
+              if ENV.key?('GITHUB_ACTIONS')
+                # TODO: determine file and position within the file
+                puts "::warning file=metadata.json::#{message}"
+              else
+                warn message
+              end
+
+              next
+            end
+
             majors.each do |puppet_version|
               if AIO.has_aio_build?(os, release, puppet_version[:value])
                 yield [os, release, puppet_version]
+              # TODO: also match requirement here
               elsif PuppetMetadata::OperatingSystem.os_release_puppet_version(os, release) == puppet_version[:value]
                 yield [os, release, distro_puppet_version.merge(value: puppet_version[:value])]
               end
@@ -74,18 +95,18 @@ module PuppetMetadata
       end
     end
 
-    def puppet_beaker_test_matrix
+    def puppet_beaker_test_matrix(at)
       matrix_include = []
 
-      beaker_os_releases do |os, release, puppet_version|
-        next if puppet_version_below_minimum?(puppet_version[:value])
+      beaker_os_releases(at) do |os, release, implementation|
+        next if requirement_name_version_below_minimum?(implementation[:value])
 
-        setfile = os_release_to_beaker_setfile(os, release, puppet_version[:collection])
+        setfile = os_release_to_beaker_setfile(os, release, implementation[:collection])
         next unless setfile
 
-        name = "#{puppet_version[:name]} - #{setfile[1]}"
+        name = "#{implementation[:name]} - #{setfile[1]}"
         env = {
-          'BEAKER_PUPPET_COLLECTION' => puppet_version[:collection],
+          'BEAKER_PUPPET_COLLECTION' => implementation[:collection],
           'BEAKER_SETFILE' => setfile[0],
         }
 
@@ -108,29 +129,7 @@ module PuppetMetadata
       matrix_include
     end
 
-    def github_action_test_matrix
-      matrix_include = []
-
-      beaker_os_releases do |os, release, puppet_version|
-        next if puppet_version_below_minimum?(puppet_version[:value])
-
-        setfile = os_release_to_beaker_setfile(os, release, puppet_version[:collection])
-        next unless setfile
-
-        matrix_include << {
-          name: "#{puppet_version[:name]} - #{setfile[1]}",
-          setfile: {
-            name: setfile[1],
-            value: setfile[0],
-          },
-          puppet: puppet_version,
-        }
-      end
-
-      matrix_include
-    end
-
-    def puppet_version_below_minimum?(version)
+    def requirement_name_version_below_minimum?(version)
       return false unless version && options[:minimum_major_puppet_version]
 
       Gem::Version.new(version) < Gem::Version.new(options[:minimum_major_puppet_version])
@@ -140,10 +139,10 @@ module PuppetMetadata
       PuppetMetadata::Beaker.os_release_to_setfile(
         os,
         release,
-        use_fqdn: options[:beaker_use_fqdn],
         pidfile_workaround: options[:beaker_pidfile_workaround],
         domain: options[:domain],
         puppet_version: puppet_collection,
+        hosts: options[:beaker_hosts],
       )
     end
   end
